@@ -89,12 +89,12 @@ btmix <- function(formula, data, k, subset, weights,
   }
 
   ## select model (if desired)
-  if (!is.null(which) & class(z) == "stepFlexmix"){
+  if (!is.null(which) & inherits(z, "stepFlexmix")){
     z <- getModel(z, which = which)
   }
   
   ## classify
-  if (class(z) == "flexmix") {
+  if (inherits(z, "flexmix")) {
     z <- as(z, "btmix")
     z@flx.call <- z@call
     z@call <- cl
